==> localnews-admin-integration-1.3.4-sources.jar: com/bxm/localnews/admin/service/fallback/QuartzIntegrationFallbackFactory.java <==
package com.bxm.localnews.admin.service.fallback;

import com.bxm.localnews.admin.param.MonitorTaskBuildParam;
import com.bxm.localnews.admin.param.PublishNewsBuildParam;
import com.bxm.localnews.admin.param.PushMsgBuildParam;
import com.bxm.localnews.admin.service.QuartzIntegrationService;
import feign.hystrix.FallbackFactory;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Component;

@Component
public class QuartzIntegrationFallbackFactory implements FallbackFactory<QuartzIntegrationService> {

    private static final Logger LOGGER = LoggerFactory.getLogger(QuartzIntegrationFallbackFactory.class);

    @Override
    public QuartzIntegrationService create(Throwable throwable) {
        return new QuartzIntegrationService() {

            @Override
            public ResponseEntity<String> addMonitor(MonitorTaskBuildParam param) {
                LOGGER.error(param.toString());
                LOGGER.error(throwable.getMessage(), throwable);
                return null;
            }

            @Override
            public ResponseEntity<String> removeMonitor(Long monitorId) {
                LOGGER.error("monitorId:{}", monitorId);
                LOGGER.error(throwable.getMessage(), throwable);
                return null;
            }

            @Override
            public ResponseEntity<String> addPublish(PublishNewsBuildParam param) {
                LOGGER.error(param.toString());
                LOGGER.error(throwable.getMessage(), throwable);
                return null;
            }

            @Override
            public ResponseEntity<String> addPush(PushMsgBuildParam param) {
                LOGGER.error(param.toString());
                LOGGER.error(throwable.getMessage(), throwable);
                return null;
            }

            @Override
            public ResponseEntity<String> removePush(Long messageId) {
                LOGGER.error("messageId:{}", messageId);
                LOGGER.error(throwable.getMessage(), throwable);
                return null;
            }
        };
    }
}

==> localnews-admin-integration-3.1.0-sources.jar: com/bxm/localnews/admin/service/fallback/QuartzIntegrationFallbackFactory.java <==
package com.bxm.localnews.admin.service.fallback;

import com.bxm.localnews.admin.param.*;
import com.bxm.localnews.admin.service.QuartzIntegrationService;
import feign.hystrix.FallbackFactory;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Component;

@Component
public class QuartzIntegrationFallbackFactory implements FallbackFactory<QuartzIntegrationService> {

    private static final Logger LOGGER = LoggerFactory.getLogger(QuartzIntegrationFallbackFactory.class);

    @Override
    public QuartzIntegrationService create(Throwable throwable) {
        return new QuartzIntegrationService() {

            @Override
            public ResponseEntity<String> addMonitor(MonitorTaskBuildParam param) {
                LOGGER.error(param.toString());
                LOGGER.error(throwable.getMessage(), throwable);
                return null;
            }

            @Override
            public ResponseEntity<String> removeMonitor(Long monitorId) {
                LOGGER.error("monitorId:{}", monitorId);
                LOGGER.error(throwable.getMessage(), throwable);
                return null;
            }

            @Override
            public ResponseEntity<String> addPublish(PublishNewsBuildParam param) {
                LOGGER.error(param.toString());
                LOGGER.error(throwable.getMessage(), throwable);
                return null;
            }

            @Override
            public ResponseEntity<String> addPush(PushMsgBuildParam param) {
                LOGGER.error(param.toString());
                LOGGER.error(throwable.getMessage(), throwable);
                return null;
            }

            @Override
            public ResponseEntity<String> removePush(Long messageId) {
                LOGGER.error("messageId:{}", messageId);
                LOGGER.error(throwable.getMessage(), throwable);
                return null;
            }

            @Override
            public ResponseEntity<String> createPostClickTask(AddPostClickCountParam param) {
                LOGGER.error(param.toString());
                LOGGER.error(throwable.getMessage(), throwable);
                return null;
            }

            @Override
            public ResponseEntity<String> removePostClickTask(Long postId) {
                LOGGER.error(postId.toString());
                LOGGER.error(throwable.getMessage(), throwable);
                return null;
            }

            @Override
            public ResponseEntity<String> sendOptimizationNotice(OptimizationNoticeParam param) {
                LOGGER.error(param.toString());
                LOGGER.error(throwable.getMessage(), throwable);
                return new ResponseEntity<String>("调用失败",HttpStatus.BAD_REQUEST);
            }

            @Override
            public ResponseEntity<String> deleteOptimizationNotice(OptimizationNoticeParam param) {
                LOGGER.error(param.getId().toString());
                LOGGER.error(throwable.getMessage(), throwable);
                return new ResponseEntity<String>("调用失败",HttpStatus.BAD_REQUEST);
            }
        };
    }
}
